@@ -1,14 +1,13 @@
 //! Load and disply simple SVG files in Bevy.
 //!
 //! This crate provides a Bevy `Plugin` to easily load and display a simple SVG file.
-//! It currently only works for the most simple SVGs.
 //!
 //! ## Usage
 //! Simply add the crate in your `Cargo.toml` and add the plugin to your app
 //!
 //! ```rust
 //! fn main() {
-//!     App::build()
+//!     App::new()
 //!         .add_plugin(bevy_svg::prelude::SvgPlugin)
 //!         .run();
 //! }
@@ -30,14 +29,16 @@
 mod bundle;
 mod loader;
 mod plugin;
+mod render;
 mod svg;
-mod tessellation;
-mod vertex_buffer;
 
-/// Import this module as `use bevy_svg::prelude::*` to get
-/// convenient imports.
+/// Import this module as `use bevy_svg::prelude::*` to get convenient imports.
 pub mod prelude {
-    pub use crate::{bundle::SvgBundle, plugin::SvgPlugin, svg::{Svg, Origin}};
+    pub use crate::{plugin::SvgPlugin, svg::{Svg, Origin}};
+    #[cfg(feature = "2d")]
+    pub use crate::bundle::Svg2dBundle;
+    #[cfg(feature = "3d")]
+    pub use crate::bundle::Svg3dBundle;
     pub use lyon_tessellation::{
         FillOptions, FillRule, LineCap, LineJoin, Orientation, StrokeOptions,
     };
